Turn a single of list of pathr objects in a data.frame for analysis.

pathr_to_df(x)

Arguments

x

A pathr object.

Value

A data.frame with as many rows as there were pathr objects.

Examples

urls <- c(
  "https://github.com/KoderKow/pathr1",
  "https://github.com/KoderKow/pathr2"
)

x <- parse_url(urls)

d <- pathr_to_df(x)

d
#>                                  url scheme   hostname host_info_name
#> 1 https://github.com/KoderKow/pathr1  https github.com         github
#> 2 https://github.com/KoderKow/pathr2  https github.com         github
#>   host_info_extension port            path file_dir file_name file_ext query
#> 1                 com <NA> KoderKow/pathr1     <NA>      <NA>     <NA>  <NA>
#> 2                 com <NA> KoderKow/pathr2     <NA>      <NA>     <NA>  <NA>
#>   params fragment username password
#> 1   <NA>     <NA>     <NA>     <NA>
#> 2   <NA>     <NA>     <NA>     <NA>